Information Leakage is an application weakness where an application
reveals sensitive data, such as technical details of the web application,
environment, or user-specific data. Sensitive data may be used by an
attacker to exploit the target web application, its hosting network,
or its users.



In its most common form, information leakage is the result of one or more
of the following conditions:

* A failure to scrub out HTML/Script comments containing sensitive
information

* Improper application or server configurations

* Improper application error handling
